%--------------------------------------------------------------------------
% File     : GRP027-1 : TPTP v3.3.0. Bugfixed v1.2.1.
% Domain   : Group Theory (Named groups)
% Problem  : All groups of order 5 are cyclic
% Version  : [MOW76] axioms.
% English  : There exists an element in G that generates all other 
%            elements by taking powers of that element.

% Refs     : [MOW76] McCharen et al. (1976), Problems and Experiments for a
% Source   : [TPTP]
% Names    : 

% Status   : Satisfiable
% Rating   : 0.50 v3.3.0, 0.33 v3.2.0, 0.80 v3.1.0, 0.67 v2.7.0, 0.33 v2.6.0, 0.86 v2.5.0, 0.67 v2.3.0, 1.00 v2.1.0
% Syntax   : Number of clauses     :   24 (   1 non-Horn;  17 unit;  18 RR)
%            Number of atoms       :   42 (   9 equality)
%            Maximal clause size   :    6 (   2 average)
%            Number of predicates  :    3 (   0 propositional; 2-4 arity)
%            Number of functors    :   10 (   6 constant; 0-3 arity)
%            Number of variables   :   43 (   0 singleton)
%            Maximal term depth    :    5 (   1 average)

% Comments : This theorem is proven via the fact that any element raised 
%            to the power of the group gives the identity element back, 
%            and that therefore only powers up to 5 in this case need 
%            be investigated.
% Bugfixes : v1.2.1 - Bugfix in GRP006-0.ax.
%--------------------------------------------------------------------------
%----Include the axioms for named groups 
include('Axioms/GRP006-0.ax').
%--------------------------------------------------------------------------
%----Elements of the group of order 5 
cnf(a_in_group,hypothesis,
    ( group_member(a,g) )).

cnf(b_in_group,hypothesis,
    ( group_member(b,g) )).

cnf(c_in_group,hypothesis,
    ( group_member(c,g) )).

cnf(d_in_group,hypothesis,
    ( group_member(d,g) )).

cnf(i_in_group,hypothesis,
    ( group_member(i,g) )).

cnf(i_is_identity,hypothesis,
    ( identity_for(g) = i )).

cnf(all_of_group,hypothesis,
    ( ~ group_member(X,g)
    | X = a
    | X = b
    | X = c
    | X = d
    | X = i )).

cnf(multiplication_to_identity,hypothesis,
    ( multiply(g,X,multiply(g,X,multiply(g,X,multiply(g,X,X)))) = i )).

cnf(all_multiply_to_identity,hypothesis,
    (  not_power_of(g,X) != X )).

%----Denial of theorem : For all X in g, there exists a Y such that X<>Y, 
%----and X^2<>Y, and X^3<>Y, and X^4<>Y, and X^5<>Y.
cnf(x2_is_not_power,negated_conjecture,
    ( ~ product(g,X,X,not_power_of(g,X)) )).

cnf(x3_is_not_power,negated_conjecture,
    ( ~ product(g,X,multiply(g,X,X),not_power_of(g,X)) )).

cnf(x4_is_not_power,negated_conjecture,
    ( ~ product(g,X,multiply(g,X,multiply(g,X,X)),not_power_of(g,X)) )).

cnf(x5_is_not_power,negated_conjecture,
    ( ~ product(g,X,multiply(g,X,multiply(g,X,multiply(g,X,X))),not_power_of(g,X)) )).

%--------------------------------------------------------------------------
