%==============================================================================
%----This outputs TPTP Problem Set clauses in a format acceptable to 
%----the SMT standard format
%----
%----Written by Geoff Sutcliffe, September, 1994.
%----Extended for FOF by Mark Stickel, February 1998.
%----Made pretty FOF format by Geoff Sutcliffe, September 1998.
%----Modified to remove and and or by Geoff Sutcliffe, March 1999.
%----Fixed to cope with xor by Geoff Sutcliffe, November 2001.
%==============================================================================
%==============================================================================
%----Generic output
%==============================================================================
%------------------------------------------------------------------------------
%----Output an atom with variables in SMT format
output_smt_term(Variable):-
    looks_like_a_variable(Variable),
    !,
    write('?'),
    write(Variable).

output_smt_term([OneTerm]):-
    !,
    output_smt_term(OneTerm).

output_smt_term([FirstTerm|RestOfTerms]):-
    !,
    output_smt_term(FirstTerm),
    write(' '),
    output_smt_term(RestOfTerms).

%----Negative integers
output_smt_term(NegativeInteger):-
    number(NegativeInteger),
    NegativeInteger < 0,
    !,
    abs(NegativeInteger,PositiveInteger),
    write('(~ '),
    write(PositiveInteger),
    write(')').

%----Translate atomic symbols
output_smt_term(Symbol):-
    atomic(Symbol),
    tptp2X_member((Symbol)-(SMTSymbol),
[('$tptp_equal')-('='),('$plus_int')-('+'),('$greater_int')-('>'),
('$int')-('Int'),('$true')-(true),('$false')-(false),('$distinct')-(distinct)]),
    !,
    write(SMTSymbol).

%----Normal atomic things
output_smt_term(Atomic):-
    atomic(Atomic),
    !,
    writeq(Atomic).

output_smt_term(T1*T2) :-
    !,
    output_prefix_formula(smt,T1,0,0,outermost),
    write(' '),
    output_prefix_formula(smt,T2,0,0,outermost).

output_smt_term(Name : Type):-
    !,
    write('SHOULD NEVER DO THIS').

%----Complex terms
output_smt_term(Complex):-
    Complex =.. [Symbol|Arguments],
    write('('),
    output_smt_term(Symbol),
    write(' '),
    output_smt_term(Arguments),
    write(')').
%------------------------------------------------------------------------------
%----Output a quantified variable
smt_output_variable(Variable:Thing):-
    write('('),
    output_smt_term(Variable),
    write(' '),
    output_prefix_formula(smt,Thing,0,0,outermost),
    write(')').

smt_output_variable(Variable:=Thing):-
    smt_output_variable(Variable:Thing).
%------------------------------------------------------------------------------
%----Output an atom
smt_output_atom(Atom):-
    output_smt_term(Atom).
%------------------------------------------------------------------------------
%==============================================================================
%----FOF output
%==============================================================================
%------------------------------------------------------------------------------
smt_let_type([Variable:='$tptp_equal'(_,_)],_,flet):-
    !.

smt_let_type([Variable:=Value],_,flet):-
    tptp_non_atomic_formula(Value),
    !.

%----This assumes all things that look like terms really are. But they can
%----be predicates, so I need to dig into the formula - TO DO
smt_let_type([Variable:=Value],_,let):-
    !.

%----Otherwise something is wrong
smt_let_type([Variable:=_],_,_):-
    write('ERROR: In := definitions --->'),
    write(Variable),
    nl,
    fail.
%------------------------------------------------------------------------------
%----Recognise and split up quantified formulae
smt_quantified_formula(QuantifiedFormula,SMTQuantifier,Variables,
Formula):-
    QuantifiedFormula =.. [:,Quantification,Formula],
    !,
    Quantification =.. [Quantifier,Variables],
    tptp2X_member(ct(Quantifier,SMTQuantifier),[ct('!',forall),ct('?',exists),
ct(':=',SMTLet)]),
    ( Quantifier == ':=' ->
        smt_let_type(Variables,Formula,SMTLet)
    ; true).
%------------------------------------------------------------------------------
%----Recognise and split up binary formulae
smt_binary_formula(BinaryFormula,SMTConnective,LHS,RHS):-
    BinaryFormula =.. [Connective,LHS,RHS],
    tptp2X_member((Connective)-(SMTConnective),
[('<=>')-('iff'),('<~>')-('xor'),('=>')-('implies'),('&')-('and'),
(';')-('or'),('|')-('or')]).
%----Both needed after shorten which sets '|' somewhere - need to check
%----|;BUG
%------------------------------------------------------------------------------
%----Recognise and split up unary formulae
smt_unary_formula(UnaryFormula,SMTConnective,Formula):-
    UnaryFormula =.. [Connective,Formula],
%----Had to use ()s due to some Prolog confusion about -
    tptp2X_member((Connective)-(SMTConnective),[('~')-('not')]).
%------------------------------------------------------------------------------
%----The format for outputing quantified formulae in oscar format
%----FormulaPrefix,VariablesPrefix,VariablesSeparator,VariablesSuffix,
%----FormulaSuffix
smt_quantified_format('(',' ',' ',' ',' )').

%----PrefixBracket,ConnectivePrefix,ConnectiveSuffix,SuffixBracket
smt_binary_format('(','','',' )').

%----FormulaPrefix,ConnectiveSuffix,FormulaSuffix
smt_unary_format('(',' ',' )').
%------------------------------------------------------------------------------
%----Write extrasorts-declarations for the sort symbols occuring in a type;
%----uses an asserted predicate to check which ones have already been 
%----written away.
:- dynamic asserted_smt_extrasort/1.
output_smt_extrasorts([]) :-
    !.

output_smt_extrasorts([Type|Types]) :-
    !,
    output_smt_extrasorts(Type),
    output_smt_extrasorts(Types).

output_smt_extrasorts('$int') :-
    !.

output_smt_extrasorts(Type) :-
    asserted_smt_extrasort(Type),
    !.

output_smt_extrasorts(Type) :-
    \+ atomic(Type),
    Type =.. [F | Types],
    !,
    memberchk(F, [*, >]),
    output_smt_extrasorts(Types).

output_smt_extrasorts(Type) :-
    atomic(Type),
    assert(asserted_smt_extrasort(Type)),
    write(':extrasorts ('),
    output_prefix_formula(smt,Type,0,0,outermost),
    write(')'),
    nl.

%------------------------------------------------------------------------------
%----If the formulae has an acceptable status then output
output_smt_formulae([]).

%----Type signature for proposition
output_smt_formulae([xff(Name,type,F:'$o')|RestOfFormulae]):-
    !,
    write('; '),
    write(Name),
    nl,
    write(':extrapreds(('),
    write(F),
    write(' '),
    output_prefix_formula(smt,Type,0,0,outermost),
    write('))'),
    nl,
    nl,
    output_smt_formulae(RestOfFormulae).

%----Type signatuer for predicate
output_smt_formulae([xff(Name,type,F:(Type>'$o'))|RestOfFormulae]):-
    !,
    write('; '),
    write(Name),
    nl,
    output_smt_extrasorts(Type),
    write(':extrapreds (('),
    write(F),
    write(' '),
    output_prefix_formula(smt,Type,0,0,outermost),
    write('))'),
    nl,
    nl,
    output_smt_formulae(RestOfFormulae).

%----Type signature for functions
output_smt_formulae([xff(Name,type,F:Type)|RestOfFormulae]):-
    !,
    write('; '),
    write(Name),
    nl,
    output_smt_extrasorts(Type),
    write(':extrafuns (('),
    write(F),
    write(' '),
    output_prefix_formula(smt,Type,0,0,outermost),
    write('))'),
    nl,
    nl,
    output_smt_formulae(RestOfFormulae).

%----Conjecture
output_smt_formulae([xff(Name,conjecture,Formula)|RestOfFormulae]):-
    write('; '),
    write(Name),
    nl,
    write(':formula '),
    nl,
    output_generic_prefix_formula(smt,Formula),
    nl,
    nl,
    output_smt_formulae(RestOfFormulae).

%----Everything else assumed to be axiom-like
output_smt_formulae([xff(Name,_,Formula)|RestOfFormulae]):-
    write('; '),
    write(Name),
    nl,
    write(':assumption '),
    nl,
    output_generic_prefix_formula(smt,Formula),
    nl,
    nl,
    output_smt_formulae(RestOfFormulae).

%------------------------------------------------------------------------------
%----Output all the formulae in smt format
smt(smt,Formulae,_):-
    tptp_formulae(Formulae),
    write('(benchmark name'),
    nl,
    write(':logic AUFLIA'),
    nl,
    nl,
    output_smt_formulae(Formulae),
    write(')'),
    nl.
%------------------------------------------------------------------------------
%----Provide information about the smt format
smt_format_information(';','.smt').
%------------------------------------------------------------------------------
%----Provide information about the smt file
smt_file_information(format,smt,'SMT format').
%------------------------------------------------------------------------------
